==> unixODBC-1.8.8.tar.gz: unixODBC-1.8.8/include/sqi.h <==
#ifndef _SQI_H
#define _SQI_H

#include <time.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include <sqlext.h>									/* if you do not want to have anything to	*/
													/* do with ODBC then just create the few 	*/
													/* defines/types that are used here			*/
#include <ini.h>
#include <lst.h>
#include <log.h>
#include <sqp.h>

#define SQI_SUCCESS 1
#define SQI_ERROR 0


/***********************
 * COLUMN
 ***********************/
typedef struct tSQICOLUMN
{
	int		nCol;									/* lst does not support nCurrentItem anymore*/
													/* so store here. This is used to index into*/
													/* our row data.							*/

	/* EVERYTHING YOU WOULD EVER WANT TO KNOW ABOUT THE COLUMN. WORKS GREAT WITH ODBC			*/
	int		bSQL_DESC_AUTO_UNIQUE_VALUE;			/* IS AUTO INCREMENT COL?					*/
	char	*pszSQL_DESC_BASE_COLUMN_NAME;			/* empty string if N/A						*/
	char	*pszSQL_DESC_BASE_TABLE_NAME;			/* empty string if N/A						*/
	int		bSQL_DESC_CASE_SENSITIVE;				/* IS CASE SENSITIVE COLUMN?				*/
	char	*pszSQL_DESC_CATALOG_NAME;				/* empty string if N/A						*/
	int		nSQL_DESC_CONCISE_TYPE;					/* ie SQL_CHAR, SQL_TYPE_TIME...			*/
	int		nSQL_DESC_DISPLAY_SIZE;					/* max digits required to display			*/
	int		bSQL_DESC_FIXED_PREC_SCALE;				/* has data source specific precision?		*/
	char	*pszSQL_DESC_LABEL;						/* display label, col name or empty string	*/
	int		nSQL_DESC_LENGTH;						/* strlen or bin size						*/
	char	*pszSQL_DESC_LITERAL_PREFIX;			/* empty string if N/A						*/
	char	*pszSQL_DESC_LITERAL_SUFFIX;			/* empty string if N/A						*/
	char	*pszSQL_DESC_LOCAL_TYPE_NAME;			/* empty string if N/A						*/
	char	*pszSQL_DESC_NAME;						/* col alias, col name or empty string		*/
	int		nSQL_DESC_NULLABLE;						/* SQL_NULLABLE, _NO_NULLS or _UNKNOWN		*/
	int		nSQL_DESC_NUM_PREC_RADIX;				/* 2, 10, or if N/A... 0 					*/
	int		nSQL_DESC_OCTET_LENGTH;					/* max size									*/
	int		nSQL_DESC_PRECISION;					/*											*/
	int		nSQL_DESC_SCALE;						/*											*/
	char	*pszSQL_DESC_SCHEMA_NAME;				/* empty string if N/A						*/
	int		nSQL_DESC_SEARCHABLE;					/* can be in a filter ie SQL_PRED_NONE...	*/
	char	*pszSQL_DESC_TABLE_NAME;                /* empty string if N/A						*/
	int		nSQL_DESC_TYPE;							/* SQL data type ie SQL_CHAR, SQL_INTEGER..	*/
	char	*pszSQL_DESC_TYPE_NAME;					/* DBMS data type ie VARCHAR, MONEY...		*/
	int		nSQL_DESC_UNNAMED;						/* qualifier for SQL_DESC_NAME ie SQL_NAMED	*/
	int		bSQL_DESC_UNSIGNED;						/* if signed FALSE else TRUE				*/
	int		nSQL_DESC_UPDATABLE;					/* ie SQL_ATTR_READONLY, SQL_ATTR_WRITE...	*/

	int		bPimaryKey;								/* is a pkey or is part of a pkey			*/

} SQICOLUMN, *HSQICOLUMN;


/***********************
 * TABLE
 *
 * 1. This can be a dynaset or a root table.
 * 2. hBase==NULL if root table
 ***********************/
typedef struct tSQITABLE
{
	char			*pszTableName;					/* mandatory and must be unique (is cursor name for cursors)		*/
	char			*pszFileName;					/* optional but usually present							   			*/
	HLST			hColHdrs;						/* list of HSQLCOLUMN s												*/
	HLST			hRows;
	int				nRefs;							/* init to 0. only free table when refs < 1 						*/
	struct			tSQITABLE	*hBase;				/* this is the table we were derived from. NULL if root table.		*/

} SQITABLE, *HSQITABLE;


/***********************
 * STATEMENT
 ***********************/

typedef struct tSQISTMT
{
	int			nType;					/* enumLanguageParts (whats in pParsedSQL)			*/
	void 		*pParsedSQL;			/* POINTS TO A STRUCT CONTAINING THE PARSED SQL		*/
	char		*pszSQL;				/* sqiOpen WILL strdup GIVEN SQL COMMAND HERE		*/
	HSQITABLE	hTableResult;			/* NULL if no result 								*/
	HLOG		hLog;					/* ERRORS AND WARNINGS etc							*/
	void		*hSQI;					/* parent											*/
	char		szMsg[1024];			/* buffer to format messages						*/
	long		nRowsAffected;			/* only valid for UPDATE, DELETE, INSERT			*/

} SQISTMT, *HSQISTMT;


/***********************
 * MAIN HANDLE FOR SQI FUNCTIONS
 ***********************/
typedef struct tSQI
{
	char		*pszCatalogFile;		/* file name of catalog								*/
	HLST		hStmtList;				/* list of active statement							*/
	HLOG		hLog;					/* ERRORS AND WARNINGS etc							*/
	char		szMsg[1024];			/* buffer to format messages						*/

} SQI, *HSQI;


/***********************
 * GLOBALS (yuck):
 *
 * This is a list of loaded root tables. Basically; all table files
 * listed in the catalog are loaded upon sqiOpen() and flushed to
 * disk on sqiClose().
 *
 * NOTE: This technique is only usefull at this, proof-of-concept,
 *       stage. A production version of SQI will have a tiny process
 *       to manage the table cache. So for now, be aware that SQI
 *       should NOT be used for concurrent access to the data.
 ***********************/
HLST		hTableCache;


/*********************************************************************************************
 * INTERFACE
 *********************************************************************************************/
#if defined(__cplusplus)
         extern  "C" {
#endif


/***********************
 * sqiClose
 *
 * Frees memory used by hSQI. Frees references to table
 * cache. Tables freed when last ref is being removed.
 *
 * 1.
 *
 * see... sqiOpen
 ***********************/
int sqiClose( HSQI hSQI );

/********************************************
 * sqiCloseStmt
 *
 *
 ********************************************/
int sqiCloseStmt( HSQISTMT hStmt );

/********************************************
 * sqiColumns
 *
 * Returns a table result listing all columns in
 * the given table... else NULL.
 *
 * Ensure that the result is freed...
 *
 ********************************************/
int sqiColumns( HSQISTMT hStmt, char *pszTableName );

/***********************
 * sqiExecute
 *
 * Executes an SQL statement.
 *
 * see...
 ***********************/
int sqiExecute( HSQISTMT hStmt );

/***********************
 * sqiFreeResult
 *
 * Frees result set.
 *
 * see...
 ***********************/
int sqiFreeResult( HSQISTMT hStmt );

/***********************
 * sqiOpen
 *
 * Create a new SQI (connection).
 *
 * see...
 ***********************/
int sqiOpen( HSQI *phSQI, char *pszCatalogFile );

/***********************
 * sqiOpenStmt
 *
 * Create a new SQISTMT
 *
 * see...
 ***********************/
int sqiOpenStmt( HSQI hSQI, HSQISTMT *phStmt );

/***********************
 * sqiPrepare
 *
 * Parses the given SQL. Is first phase of SQL validation.
 *
 * see...
 ***********************/
int sqiPrepare( HSQISTMT hStmt, char *pszSQL );

/***********************
 * sqiPrimaryKeys
 *
 * Creates a result set listing primary key columns.
 * It gets this from the PKEY=col,col... in the catalog file.
 *
 * see...
 ***********************/
int sqiPrimaryKeys( HSQISTMT hStmt, char *pszTableName );

/***********************
 * sqiSetColumn
 *
 * Copies pszValue into nRootColumn.
 *
 * see...
 ***********************/
int sqiSetColumn( HSQITABLE hTable, int nRootColumn, char *pszValue );

/***********************
 * sqiSpecialColumns
 *
 *
 *
 * see...
 ***********************/
int sqiSpecialColumns( HSQISTMT hStmt, char *pszTableName );

/***********************
 * sqiStatistics
 *
 * Creates a result set listing indexs. This will
 * be an empty result set until indexs are implemented.
 *
 * see...
 ***********************/
int sqiStatistics( HSQISTMT hStmt, char *pszTableName );

/***********************
 * sqiTables
 *
 * Creates a result set listing all tables from the catalog.
 *
 * see...
 ***********************/
int sqiTables( HSQISTMT hStmt );



/*********************************************************************************************
 * FOR INTERNAL USE
 *********************************************************************************************/

/***********************
 * _sqiCloseDatabase
 *
 * Unloads the database
 *
 ***********************/
int _sqiCloseDatabase( HLST hTables );

/***********************
 * _sqiCloseStmt
 *
 * Call back to be used by LST to free memory.
 *
 ***********************/
void _sqiCloseStmt( void *pData );

/***********************
 * _sqiCloseTable
 *
 * Frees table. Used as a call back (by LST) and called directly.
 *
 * see...
 ***********************/
void _sqiCloseTable( void *pData );

/***********************
 * _sqiDump
 *
 * Dumps parsed SQL using printf
 *
 * 1. for debugging
 *
 * see...
 ***********************/
int _sqiDump( HSQISTMT hStmt );

/***********************
 * _sqiDumpTable
 *
 * Dump table data
 *
 * 1. for debugging
 *
 * see...
 ***********************/
void _sqiDumpTable( HSQITABLE hTable );

/***********************
 * _sqiExecuteParsedSQL
 *
 * Tries to create a HSQLTABLE using the parsed SQL and the table cache.
 *
 * 1. -1 means no rows affected and phTable = NULL
 * 2. sqlError will return an error message if something went wrong
 *
 * see...
 ***********************/
int _sqiExecuteParsedSQL( HSQISTMT hStmt );

/***********************
 * _sqiFreeColumnHeader
 *
 * Call back to be used by LST when free items from list.
 *
 * see...
 ***********************/
void _sqiFreeColumnHeader( void *pData );

/***********************
 * _sqiFreeDataRow
 *
 * Call back to be used by LST when free items from list.
 *
 * see...
 ***********************/
void _sqiFreeDataRow( void *pData );

/***********************
 * _sqiFreeParsedSQL
 *
 * Frees memory used by parsed SQL.
 *
 * 1.
 *
 * see... sqiPrepare
 ***********************/
int _sqiFreeParsedSQL( HSQISTMT hStmt );

/***********************
 * _sqiGetTableFileName
 *
 * Does a table name lookup in the catalog file and returns the table-file file name.
 *
 * see...
 ***********************/
int _sqiGetTableFileName( HSQISTMT hStmt, char *pszCatalogFile, char *pszTableName, char *pszTableFile );

/***********************
 * _sqiGetTableHandle
 *
 * Tries to find/return the table handle from the table cache.
 *
 * see...
 ***********************/
HSQITABLE _sqiGetTableHandle( char *pszTableName );

/***********************
 * _sqiLoadTable
 *
 * Loads a table file into a SQITABLE structure.
 *
 * see... _sqiSaveTable
 ***********************/
int _sqiOpenTable( HSQITABLE *phTable, char *pszCatalogFile, char *pszTableName, char *pszTableFile );

/***********************
 * _sqiLoadTableColHdrs
 *
 * Loads column names from the first line of a table file.
 *
 * see...
 ***********************/
int _sqiLoadTableColHdrs( char *pszCatalogFile, char *pszTableName, HLST hColHdrs, FILE *hFile );

/***********************
 * _sqiNewColumnHeader
 *
 * Creates and inits a new SQICOLUMN
 *
 * 1. for internal use only
 *
 * see... _sqiSaveTable
 ***********************/
HSQICOLUMN _sqiNewColumnHeader( int nCol, char *pszCatalogFile, char *pszTableName, char *pszColumnName );

/***********************
 * _sqiSaveTable
 *
 * Write all of the data in hTable to a file of the format;
 *
 * Row  1  ColumnHeaders:		colname,colname,colname...
 * Row >1           Data:		value,value,value...
 *
 * 1. for debugging and internal use only
 *
 * see... _sqiLoadTable
 ***********************/
int _sqiSaveTable( HSQITABLE hTable, char *pszFileName );

#if defined(__cplusplus)
         }
#endif


#endif

==> unixODBC-1.8.13.tar.gz: unixODBC-1.8.13/include/sqi.h <==
#ifndef _SQI_H
#define _SQI_H

#include <time.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include <sqlext.h>									/* if you do not want to have anything to	*/
													/* do with ODBC then just create the few 	*/
													/* defines/types that are used here			*/
#include <ini.h>
#include <lst.h>
#include <log.h>
#include <sqp.h>

int yyparse();

#define SQI_SUCCESS 1
#define SQI_ERROR 0


/***********************
 * COLUMN
 ***********************/
typedef struct tSQICOLUMN
{
	int		nCol;									/* lst does not support nCurrentItem anymore*/
													/* so store here. This is used to index into*/
													/* our row data. 0 based.					*/

	/* EVERYTHING YOU WOULD EVER WANT TO KNOW ABOUT THE COLUMN. WORKS GREAT WITH ODBC			*/
	int		bSQL_DESC_AUTO_UNIQUE_VALUE;			/* IS AUTO INCREMENT COL?					*/
	char	*pszSQL_DESC_BASE_COLUMN_NAME;			/* empty string if N/A						*/
	char	*pszSQL_DESC_BASE_TABLE_NAME;			/* empty string if N/A						*/
	int		bSQL_DESC_CASE_SENSITIVE;				/* IS CASE SENSITIVE COLUMN?				*/
	char	*pszSQL_DESC_CATALOG_NAME;				/* empty string if N/A						*/
	int		nSQL_DESC_CONCISE_TYPE;					/* ie SQL_CHAR, SQL_TYPE_TIME...			*/
	int		nSQL_DESC_DISPLAY_SIZE;					/* max digits required to display			*/
	int		bSQL_DESC_FIXED_PREC_SCALE;				/* has data source specific precision?		*/
	char	*pszSQL_DESC_LABEL;						/* display label, col name or empty string	*/
	int		nSQL_DESC_LENGTH;						/* strlen or bin size						*/
	char	*pszSQL_DESC_LITERAL_PREFIX;			/* empty string if N/A						*/
	char	*pszSQL_DESC_LITERAL_SUFFIX;			/* empty string if N/A						*/
	char	*pszSQL_DESC_LOCAL_TYPE_NAME;			/* empty string if N/A						*/
	char	*pszSQL_DESC_NAME;						/* col alias, col name or empty string		*/
	int		nSQL_DESC_NULLABLE;						/* SQL_NULLABLE, _NO_NULLS or _UNKNOWN		*/
	int		nSQL_DESC_NUM_PREC_RADIX;				/* 2, 10, or if N/A... 0 					*/
	int		nSQL_DESC_OCTET_LENGTH;					/* max size									*/
	int		nSQL_DESC_PRECISION;					/*											*/
	int		nSQL_DESC_SCALE;						/*											*/
	char	*pszSQL_DESC_SCHEMA_NAME;				/* empty string if N/A						*/
	int		nSQL_DESC_SEARCHABLE;					/* can be in a filter ie SQL_PRED_NONE...	*/
	char	*pszSQL_DESC_TABLE_NAME;                /* empty string if N/A						*/
	int		nSQL_DESC_TYPE;							/* SQL data type ie SQL_CHAR, SQL_INTEGER..	*/
	char	*pszSQL_DESC_TYPE_NAME;					/* DBMS data type ie VARCHAR, MONEY...		*/
	int		nSQL_DESC_UNNAMED;						/* qualifier for SQL_DESC_NAME ie SQL_NAMED	*/
	int		bSQL_DESC_UNSIGNED;						/* if signed FALSE else TRUE				*/
	int		nSQL_DESC_UPDATABLE;					/* ie SQL_ATTR_READONLY, SQL_ATTR_WRITE...	*/

	int		bPimaryKey;								/* is a pkey or is part of a pkey			*/

} SQICOLUMN, *HSQICOLUMN;


/***********************
 * TABLE
 *
 * 1. This can be a dynaset or a root table.
 * 2. hBase==NULL if root table
 ***********************/
typedef struct tSQITABLE
{
	char			*pszFileName;					/* file name of table. optional but usually present					*/
	char			*pszTableName;					/* mandatory and must be unique (is cursor name for cursors)		*/
	char			*pszDescription;				/* brief description of table										*/
	int				bFixedColumns;					/* are the columns stored as their max width						*/
	char			cDelimitChar;					/* cols are delimited by this ( cDelimitChar=0 if no delimit )		*/
	HLST			hColHdrs;						/* list of HSQLCOLUMN s												*/
	HLST			hRows;							/* row data. each row item is an array of char *					*/
	int				nRefs;							/* init to 0. only free table when refs < 1 						*/
	struct			tSQITABLE	*hBase;				/* this is the table we were derived from. NULL if root table.		*/

} SQITABLE, *HSQITABLE;


/***********************
 * STATEMENT
 ***********************/
typedef struct tSQISTMT
{
	int			nType;					/* enumLanguageParts (whats in pParsedSQL)			*/
	void 		*pParsedSQL;			/* POINTS TO A STRUCT CONTAINING THE PARSED SQL		*/
	char		*pszSQL;				/* sqiOpen WILL strdup GIVEN SQL COMMAND HERE		*/
	HSQITABLE	hTableResult;			/* NULL if no result 								*/
	HLOG		hLog;					/* ERRORS AND WARNINGS etc							*/
	void		*hSQI;					/* parent											*/
	char		szMsg[1024];			/* buffer to format messages						*/
	long		nRowsAffected;			/* only valid for UPDATE, DELETE, INSERT			*/

} SQISTMT, *HSQISTMT;


/***********************
 * MAIN HANDLE FOR SQI FUNCTIONS
 ***********************/
typedef struct tSQI
{
	char		*pszCatalogFile;		/* file name of catalog												*/
	char		*pszName;				/* friendly name of database										*/
	char		*pszDescription;		/* brief description of database									*/
	char		*pszDefaultPath;		/* default path to find stuff like table files (ending / optional)	*/
	HLST		hStmtList;				/* list of active statement											*/
	HLOG		hLog;					/* ERRORS AND WARNINGS etc											*/
	char		szMsg[1024];			/* buffer to format messages										*/
	HLST		hTableCache;			/* List of loaded root tables. Basically; all tables				*/
										/* are loaded upon sqiOpen() and flushed to disk    				*/
										/* on sqiClose().                                   				*/

} SQI, *HSQI;


/*********************************************************************************************
 * INTERFACE
 *********************************************************************************************/
#if defined(__cplusplus)
         extern  "C" {
#endif


/***********************
 * sqiClose
 *
 * Frees memory used by hSQI. Frees references to table
 * cache. Tables freed when last ref is being removed.
 *
 * 1.
 *
 * see... sqiOpen
 ***********************/
int sqiClose( HSQI hSQI );

/********************************************
 * sqiCloseStmt
 *
 *
 ********************************************/
int sqiCloseStmt( HSQISTMT hStmt );

/********************************************
 * sqiColumns
 *
 * Returns a table result listing all columns in
 * the given table... else NULL.
 *
 * Ensure that the result is freed...
 *
 ********************************************/
int sqiColumns( HSQISTMT hStmt, char *pszTableName );

/***********************
 * sqiExecute
 *
 * Executes an SQL statement.
 *
 * see...
 ***********************/
int sqiExecute( HSQISTMT hStmt );

/***********************
 * sqiFreeResult
 *
 * Frees result set.
 *
 * see...
 ***********************/
int sqiFreeResult( HSQISTMT hStmt );

/***********************
 * sqiOpen
 *
 * Create a new SQI (connection).
 *
 * see...
 ***********************/
int sqiOpen( HSQI *phSQI, char *pszCatalogFile );

/***********************
 * sqiOpenStmt
 *
 * Create a new SQISTMT
 *
 * see...
 ***********************/
int sqiOpenStmt( HSQI hSQI, HSQISTMT *phStmt );

/***********************
 * sqiPrepare
 *
 * Parses the given SQL. Is first phase of SQL validation.
 *
 * see...
 ***********************/
int sqiPrepare( HSQISTMT hStmt, char *pszSQL );

/***********************
 * sqiPrimaryKeys
 *
 * Creates a result set listing primary key columns.
 * It gets this from the PKEY=col,col... in the catalog file.
 *
 * see...
 ***********************/
int sqiPrimaryKeys( HSQISTMT hStmt, char *pszTableName );

/***********************
 * sqiSetColumn
 *
 * Copies pszValue into nRootColumn.
 *
 * see...
 ***********************/
int sqiSetColumn( HSQITABLE hTable, int nRootColumn, char *pszValue );

/***********************
 * sqiSpecialColumns
 *
 *
 *
 * see...
 ***********************/
int sqiSpecialColumns( HSQISTMT hStmt, char *pszTableName );

/***********************
 * sqiStatistics
 *
 * Creates a result set listing indexs. This will
 * be an empty result set until indexs are implemented.
 *
 * see...
 ***********************/
int sqiStatistics( HSQISTMT hStmt, char *pszTableName );

/***********************
 * sqiTables
 *
 * Creates a result set listing all tables from the catalog.
 *
 * see...
 ***********************/
int sqiTables( HSQISTMT hStmt );



/*********************************************************************************************
 * FOR INTERNAL USE
 *********************************************************************************************/

/***********************
 * _sqiCloseDatabase
 *
 * Unloads the database
 *
 ***********************/
int _sqiCloseDatabase( HLST hTables );

/***********************
 * _sqiCloseStmt
 *
 * Call back to be used by LST to free memory.
 *
 ***********************/
void _sqiCloseStmt( void *pData );

/***********************
 * _sqiCloseTable
 *
 * Frees table. Used as a call back (by LST) and called directly.
 *
 * see...
 ***********************/
void _sqiCloseTable( void *pData );

/***********************
 * _sqiDump
 *
 * Dumps parsed SQL using printf
 *
 * 1. for debugging
 *
 * see...
 ***********************/
int _sqiDump( HSQISTMT hStmt );

/***********************
 * _sqiDumpTable
 *
 * Dump table data
 *
 * 1. for debugging
 *
 * see...
 ***********************/
void _sqiDumpTable( HSQITABLE hTable );

/***********************
 * _sqiExecuteParsedSQL
 *
 * Tries to create a HSQLTABLE using the parsed SQL and the table cache.
 *
 * 1. -1 means no rows affected and phTable = NULL
 * 2. sqlError will return an error message if something went wrong
 *
 * see...
 ***********************/
int _sqiExecuteParsedSQL( HSQISTMT hStmt );

/***********************
 * _sqiFreeColumnHeader
 *
 * Call back to be used by LST when free items from list.
 *
 * see...
 ***********************/
void _sqiFreeColumnHeader( void *pData );

/***********************
 * _sqiFreeDataRow
 *
 * Call back to be used by LST when free items from list.
 *
 * see...
 ***********************/
void _sqiFreeDataRow( void *pData );

/***********************
 * _sqiFreeParsedSQL
 *
 * Frees memory used by parsed SQL.
 *
 * 1.
 *
 * see... sqiPrepare
 ***********************/
int _sqiFreeParsedSQL( HSQISTMT hStmt );

/***********************
 * _sqiGetTableFileName
 *
 * Does a table name lookup in the catalog file and returns the table-file file name.
 *
 * see...
 ***********************/
int _sqiGetTableFileName( HSQISTMT hStmt, char *pszCatalogFile, char *pszTableName, char *pszTableFile );

/***********************
 * _sqiGetTableHandle
 *
 * Tries to find/return the table handle from the table cache.
 *
 * see...
 ***********************/
HSQITABLE _sqiGetTableHandle( HSQI hSQI, char *pszTableName );

/***********************
 * _sqiOpenDatabase
 *
 * Init hSQI and then call this to load database
 * definition and data.
 *
 * see... _sqiCloseDatabase
 ***********************/
int _sqiOpenDatabase( HSQI hSQI );

/***********************
 * _sqiLoadTable
 *
 * Loads a table file into a SQITABLE structure.
 *
 * see... _sqiSaveTable
 ***********************/
int _sqiOpenTable( HSQITABLE *phTable, char *pszCatalogFile, char *pszTableName, char *pszTableFile );

/***********************
 * _sqiLoadTableColHdrs
 *
 * Loads column names from the first line of a table file.
 *
 * see...
 ***********************/
int _sqiLoadTableColHdrs( char *pszCatalogFile, char *pszTableName, HLST hColHdrs, FILE *hFile );

/***********************
 * _sqiNewColumnHeader
 *
 * Creates and inits a new SQICOLUMN
 *
 * 1. for internal use only
 *
 * see... _sqiSaveTable
 ***********************/
HSQICOLUMN _sqiNewColumnHeader( int nCol, char *pszDatabase, char *pszTableName, char *pszColumnName, int nType, int nSize );

/***********************
 * _sqiSaveTable
 *
 * Write all of the data in hTable to a file of the format;
 *
 * Row  1  ColumnHeaders:		colname,colname,colname...
 * Row >1           Data:		value,value,value...
 *
 * 1. for debugging and internal use only
 *
 * see... _sqiLoadTable
 ***********************/
int _sqiSaveTable( HSQITABLE hTable, char *pszFileName );



int _sqiLoadTableData( HSQITABLE hTable, FILE *hFile );

#if defined(__cplusplus)
         }
#endif


#endif
